Embedded Libraries
==================

This folder contains sources copied from other PyPI packages so that autopip can leverage existing libraries instead of
writing everything from scratch. All sources are originally licensed under MIT License.
